---
weight: 260
title: "Citation"
icon: volunteer_activism
description: "Has our library helped your research? Please cite us!"
lead: "Has our library helped your research? Please cite us!"
date: 2022-10-19T21:49:38+01:00
lastmod: 2023-08-24T16:34:38+01:00
draft: false
images: []
toc: true
aliases:
  - /docs/hpmocd/citation/
  - /hpmocd/citation/
---

```bib
@article{Santos2025,
  author    = {Santos, Guilherme O. and Vieira, Lucas S. and Rossetti, Giulio and Ferreira, Carlos H. G. and Moreira, Gladston J. P.},
  title     = {A high-performance evolutionary multiobjective community detection algorithm},
  journal   = {Social Network Analysis and Mining},
  year      = {2025},
  volume    = {15},
  number    = {1},
  pages     = {110},
  issn      = {1869-5469},
  doi       = {10.1007/s13278-025-01519-7},
  url       = {https://doi.org/10.1007/s13278-025-01519-7}
}
```

